# devkit-py
![ci-badge](https://github.com/outcome-co/devkit-py/workflows/Checks/badge.svg) ![version-badge](https://img.shields.io/badge/version-3.0.10-brightgreen)

A package containing common dev dependencies for python projects.

## Usage

```sh
poetry add -D outcome-devkit
```

## Development

Remember to run `./pre-commit.sh` when you clone the repository.
